/*
 * Copyright (C) 2008, Uwe Schmidt 
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions: 
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software. 
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE. 
 */
package org.uweschmidt.dijkstravis;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.io.File;
import java.util.Locale;

import javax.swing.JPanel;

import org.jdesktop.application.Action;
import org.jdesktop.application.Application;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.swingx.util.OS;
import org.uweschmidt.dijkstravis.gui.AboutWindow;
import org.uweschmidt.dijkstravis.gui.GraphPanel;
import org.uweschmidt.dijkstravis.gui.HelpPanel;
import org.uweschmidt.dijkstravis.gui.IntroWindow;
import org.uweschmidt.dijkstravis.gui.MenuBar;
import org.uweschmidt.dijkstravis.gui.StatusBar;
import org.uweschmidt.dijkstravis.gui.ToolBar;
import org.uweschmidt.dijkstravis.language.LocaleChangeListener;
import org.uweschmidt.dijkstravis.language.LocaleManager;
import org.uweschmidt.dijkstravis.util.SC;


public class DijkstraVisApp extends SingleFrameApplication implements LocaleChangeListener {

	@Override
	@SuppressWarnings("serial")
	protected void startup() {
		IntroWindow intro = new IntroWindow(getMainFrame());
		HelpPanel help = new HelpPanel();
		AboutWindow about = new AboutWindow();
		getMainFrame().setJMenuBar(new MenuBar(intro, help, about));
		
		JPanel foo = new JPanel(new BorderLayout());
		foo.add(GraphPanel.getInstance(), BorderLayout.CENTER);
		foo.add(help, BorderLayout.WEST);
		
		JPanel mainPanel = new JPanel(new BorderLayout());
		mainPanel.add(new ToolBar(intro, help), BorderLayout.NORTH);
		mainPanel.add(foo, BorderLayout.CENTER);
		mainPanel.add(StatusBar.getInstance(), BorderLayout.SOUTH);

		LocaleManager.addLocaleChangeListener(this);
		StatusBar.getInstance().setText(StatusBar.EMPTY_TEXT);

		if (!new File(getContext().getLocalStorage().getDirectory(), "mainFrame.session.xml").exists()) {
			getMainFrame().setPreferredSize(new Dimension(1200, 800));
			getMainFrame().setSize(1200, 800);
			getMainFrame().setLocationRelativeTo(null);
		}
		
		show(mainPanel);
		intro.setVisible(true);
	}

	public void localeChanged() {
		configureWindow(getMainFrame());
	}

	@Action
	public void exitApp() {
		exit();
	}

	@Action
	public void switchLanguage() {
		LocaleManager.setLocale(LocaleManager.getLocale() == Locale.ENGLISH ? Locale.GERMAN : Locale.ENGLISH);
	}

	public static void main(String[] args) {

		if (OS.isMacOSX()) {
			System.setProperty("com.apple.mrj.application.apple.menu.about.name", SC.getResourceMap(DijkstraVisApp.class).getString("Application.id"));
			System.setProperty("apple.laf.useScreenMenuBar", "true");
		}

		System.setProperty("swing.aatext", "true");

//		if (LocaleManager.getLocale() != Locale.ENGLISH && LocaleManager.getLocale() != Locale.GERMAN)
		LocaleManager.setLocale(Locale.ENGLISH);

		Application.launch(DijkstraVisApp.class, args);
	}

}
