/*
 * Copyright (C) 2008, Uwe Schmidt 
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions: 
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software. 
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE. 
 */
package org.uweschmidt.dijkstravis.graph;

import java.awt.geom.Point2D;
import java.util.HashSet;
import java.util.Set;

import org.apache.commons.collections15.Transformer;


public class GraphManager {
	
	private static IGraph graph = null;
	private static Transformer<INode, Point2D> layout = null;
	private static final Set<GraphChangeListener> listeners = new HashSet<GraphChangeListener>();
	
	public static void setGraphAndLayout(final IGraph graph, final Transformer<INode, Point2D> layout) {
		GraphManager.graph = graph;
		GraphManager.layout = layout;
		notifyListeners();
	}

	public static void setLayout(Transformer<INode, Point2D> layout) {
		GraphManager.layout = layout;
		notifyListeners();
	}
	
	public static void setGraph(IGraph graph) {
		GraphManager.graph = graph;
		notifyListeners();
	}
	
	public static void addGraphChangeListener(GraphChangeListener l) {
		listeners.add(l);
	}
	
	public static void removeGraphChangeListener(GraphChangeListener l) {
		listeners.remove(l);
	}

	private static void notifyListeners() {
		for (final GraphChangeListener l : listeners) {
			l.graphReplaced(graph, layout);
		}
	}

	// called by MyGraph
	public static void graphChanged() {
		for (final GraphChangeListener l : listeners) {
			l.graphChanged();
		}
	}

	public static IGraph getGraph() {
		return graph;
	}

	public static Transformer<INode, Point2D> getLayout() {
		return layout;
	}

}
