/*
 * Copyright (C) 2008, Uwe Schmidt 
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions: 
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software. 
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE. 
 */
package org.uweschmidt.dijkstravis.graph;

import java.util.Collection;

public interface IGraph {

	public void setStart(INode start);
	public INode getStart();

	public Collection<IEdge> getOutEdges(INode source);
	public Collection<IEdge> getInEdges(INode source);
	public INode getDest(IEdge edge);
	public INode getSource(IEdge edge);
	public Collection<INode> getSuccessors(INode node);
	
	public boolean containsNode(INode node);
	public boolean containsEdge(IEdge edge);
	public IEdge findEdge(INode v1, INode v2);
	
	public boolean addNode(INode node);
	public boolean addEdge(IEdge e, INode v1, INode v2);
	
	public void highlight(final INode node);
	public void highlight(final IEdge edge);

	public Collection<INode> getNodes();

	public int getNumberOfNodes();

}
