/*
 * Copyright (C) 2008, Uwe Schmidt 
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions: 
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software. 
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE. 
 */
package org.uweschmidt.dijkstravis.graph.algorithm;

import java.util.HashSet;
import java.util.Set;


public class DijkstraAlgorithmManager {
	
	private static final Set<AlgorithmProgressListener<DijkstraStepChanges>> listeners = new HashSet<AlgorithmProgressListener<DijkstraStepChanges>>();
	private static DijkstraShortestPath algo;
	private static AlgorithmProgressListener<DijkstraStepChanges> lis;
	private static boolean algoRunning = false;
	private static DijkstraStepChanges changes = null;
	
	public static void setAlgorithm(DijkstraShortestPath algo) {
		if (DijkstraAlgorithmManager.algo != null && lis != null)
			DijkstraAlgorithmManager.algo.removeProgressListener(lis);
		
		DijkstraAlgorithmManager.algo = algo;
		DijkstraAlgorithmManager.algo.addProgressListener(lis = new AlgorithmProgressListener<DijkstraStepChanges>() {
			public void initialized(int maxSteps) {
				algoRunning = true;
				changes = null;
				for (final AlgorithmProgressListener<DijkstraStepChanges> l : listeners) {
					l.initialized(maxSteps);
				}
			}
			public void reset() {
				algoRunning = false;
				changes = null;
				for (final AlgorithmProgressListener<DijkstraStepChanges> l : listeners) {
					l.reset();
				}
			}
			public void stepChanged(int step, DijkstraStepChanges changes) {
				DijkstraAlgorithmManager.changes = changes;
				for (final AlgorithmProgressListener<DijkstraStepChanges> l : listeners) {
					l.stepChanged(step, changes);
				}
			}
		});
	}

	public static void addAlgorithmProgressListener(AlgorithmProgressListener<DijkstraStepChanges> l) {
		listeners.add(l);
	}

	public static void removeAlgorithmProgressListener(AlgorithmProgressListener<DijkstraStepChanges> l) {
		listeners.remove(l);
	}
	
	public static boolean isAlgoRunning() {
		return algoRunning;
	}
	
	public static DijkstraStepChanges getCurrentStepChanges() {
		return changes;
	}
	
	public static DijkstraShortestPath getAlgorithm() {
		return algo;
	}
}
