/*
 * Copyright (C) 2008, Uwe Schmidt 
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions: 
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software. 
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE. 
 */
package org.uweschmidt.dijkstravis.graph.algorithm;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.uweschmidt.dijkstravis.graph.IEdge;
import org.uweschmidt.dijkstravis.graph.INode;


public class DijkstraStepChanges {
	private final Map<INode, Double[]> changedDistances = new HashMap<INode, Double[]>();
	private final Map<INode, IEdge[]> changedPredecessorEdges = new HashMap<INode, IEdge[]>();
	private final Map<IEdge, IEdge.Attribute[]> changedPredecessorEdgeAttributes = new HashMap<IEdge, IEdge.Attribute[]>();
	private INode minimum = null, nextMinimum = null;
	private double minimumDistance, nextMinimumDistance;
	private final Map<INode, INode.Attribute> oldAttributes = new HashMap<INode, INode.Attribute>();
	
	@Override
	public String toString() {
		return String.format("Changed nodes = %s", changedDistances.keySet());
	}

	public void setDistance(INode v, double oldDistance, double newDistance) {
		if (newDistance > oldDistance)
			System.err.println("new distance > old distance");
		changedDistances.put(v, new Double[] { oldDistance, newDistance });
		oldAttributes.put(v, v.getAttribute());
	}

	public void setPredecessorEdge(INode v, IEdge oldEdge, IEdge newEdge) {
		changedPredecessorEdges.put(v, new IEdge[] { oldEdge, newEdge });
		if (oldEdge != null)
			changedPredecessorEdgeAttributes.put(oldEdge, new IEdge.Attribute[] { oldEdge.getAttribute(), IEdge.Attribute.REMOVED_FROM_SHORTEST_PATH });
		if (newEdge != null)
			changedPredecessorEdgeAttributes.put(newEdge, new IEdge.Attribute[] { newEdge.getAttribute(), IEdge.Attribute.ADDED_TO_SHORTEST_PATH });

	}

	public double getOldDistance(INode v) {
		return changedDistances.get(v)[0];
	}

	public double getNewDistance(INode v) {
		return changedDistances.get(v)[1];
	}

	public IEdge getOldPredecessorEdge(INode v) {
		return changedPredecessorEdges.get(v)[0];
	}

	public IEdge getNewPredecessorEdge(INode v) {
		return changedPredecessorEdges.get(v)[1];
	}

	public Set<INode> getChangedNodes() {
		return changedDistances.keySet();
	}

	public void setNextMinimum(INode nextMinimum, double distance) {
		this.nextMinimum = nextMinimum;
		this.nextMinimumDistance = distance;
	}

	public INode getNextMinimum() {
		return nextMinimum;
	}

	public void setMinimum(INode minimum, double distance) {
		this.minimum = minimum;
		this.minimumDistance = distance;
	}

	public INode getMinimum() {
		return minimum;
	}

	public double getMinimumDistance() {
		return minimumDistance;
	}

	public double getNextMinimumDistance() {
		return nextMinimumDistance;
	}

	public INode.Attribute getNewAttribute(INode v) {
		return getOldDistance(v) < Double.POSITIVE_INFINITY ? INode.Attribute.PATH_IMPROVED : INode.Attribute.PATH_FOUND;
	}

	public INode.Attribute getOldAttribute(INode v) {
		return oldAttributes.get(v);
	}

	public IEdge.Attribute getOldAttribute(IEdge e) {
		return changedPredecessorEdgeAttributes.get(e)[0];
	}

	public IEdge.Attribute getNewAttribute(IEdge e) {
		return changedPredecessorEdgeAttributes.get(e)[1];
	}

}